@@ -226,7 +226,7 @@ yelp_application_cmdline (GApplication     *app,
             base = g_file_new_for_path (cur);
             new = g_file_resolve_relative_path (base, (*arguments)[i]);
             newuri = g_file_get_uri (new);
-            g_free (arguments[i]);
+            g_free ((*arguments)[i]);
             (*arguments)[i] = newuri;
             g_free (cur);
             g_object_unref (new);
